//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Class          : RadioButtonPanel
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  Carnegie Mellon University
//                  5000 Forbes Avenue
//                  Pittsburgh, PA 15213-3891
//                  e-mail: pattis@cs.cmu.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   Builds a JPanel containing radio buttons (with at most one button
// pressed at a time) with labels.  Objects in this class push/pull a
// String (the label currently pressed).
//
// Pushing is when the control calls the model to tell it about a new value.
// Pulling is when the model calls the control asking it for its current value.
//
//   Sometimes Java requires "final" parameters/variables to get a job done. This
// just ensures that the object the variable stores never changes. If Java requires
// "final" for an obscure reason, the compiler will be pretty specific about it.
//
//   Note that "no access modifier" means that the method is package
// friendly: this means the member is public to all other classes in
// the ControllerDemo package, but private elsewhere.
//
// Future Plans   : More Comments
//
// Program History:
//   3/19/02: R. Pattis - Operational for 15-100/15-111
//
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////



package controllerDemo;


import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

import java.awt.FlowLayout;

import javax.swing.ButtonGroup;  //For mutually exclusive components
import javax.swing.JPanel;
import javax.swing.JRadioButton;



class RadioButtonPanel extends JPanel
{

   public RadioButtonPanel(String[] labels, final ActionListener action)
   {
     super();
     setLayout(new FlowLayout(FlowLayout.LEFT));
     
     //Always prints a debug message and stores label of selection
     //Specify how all actions are pushed via the parameter "action"
     ActionListener updateSelectedValue = new ActionListener()
       {public void actionPerformed(ActionEvent e)
         {
           System.out.println("Debug-Controller: " + "RadioButtonPanel: " +
		                          e.getActionCommand());
 		       //System.out.println("  Action-Event = " + e);
           selectedValue = e.getActionCommand();
           if (action != null)
             action.actionPerformed(e);
         }
       };
     
     //Create a button group
     //Then, create a radio button for each label, add it to the JPanel,
     //  add it to the button group (to make the buttons exclusive), and
     //  add to it the action listner defined above  
     ButtonGroup exclusive = new ButtonGroup();
     for (int i=0; i<labels.length; i++) {
       JRadioButton temp = new JRadioButton(labels[i]);
       add(temp);
       exclusive.add(temp);
       temp.addActionListener(updateSelectedValue);  //Supports pulled data
     }
   }


  
  //Pull data when required
  String getSelectedValue()
  {return selectedValue;}



  //intance variable for pulled data
  private String selectedValue;

}


